@@ -1221,6 +1221,64 @@ g_type_interface_add_prerequisite (GType interface_type,
     }
 }
 
+/**
+ * g_type_interface_prerequisites:
+ * @interface_type: an interface type
+ * @n_prerequisites: location to return the number of prerequisites, or %NULL
+ * 
+ * Returns the prerequisites of an interfaces type.
+ * 
+ * Return value: a newly-allocated zero-terminated array of #GType containing 
+ * the prerequisites of @interface_type
+ *
+ * Since: 2.2
+ **/
+GType* /* free result */
+g_type_interface_prerequisites (GType  interface_type,
+				guint *n_prerequisites)
+{
+  TypeNode *iface;
+  
+  g_return_val_if_fail (G_TYPE_IS_INTERFACE (interface_type), NULL);
+
+  iface = lookup_type_node_I (interface_type);
+  if (iface)
+    {
+      GType *types;
+      TypeNode *inode = NULL;
+      guint i, n = 0;
+      
+      G_READ_LOCK (&type_rw_lock);
+      types = g_new0 (GType, IFACE_NODE_N_PREREQUISITES (iface) + 1);
+      for (i = 0; i < IFACE_NODE_N_PREREQUISITES (iface); i++)
+	{
+	  GType prerequisite = IFACE_NODE_PREREQUISITES (iface)[i];
+	  TypeNode *node = lookup_type_node_I (prerequisite);
+	  if (node->is_instantiatable &&
+	      (!inode || type_node_is_a_L (node, inode)))
+	    inode = node;
+	  else
+	    types[n++] = NODE_TYPE (node);
+	}
+      if (inode)
+	types[n++] = NODE_TYPE (inode);
+      
+      if (n_prerequisites)
+	*n_prerequisites = n;
+      G_READ_UNLOCK (&type_rw_lock);
+      
+      return types;
+    }
+  else
+    {
+      if (n_prerequisites)
+	*n_prerequisites = 0;
+      
+      return NULL;
+    }
+}
+
+
 static IFaceHolder*
 type_iface_peek_holder_L (TypeNode *iface,
 			  GType     instance_type)
@@ -2659,9 +2717,6 @@ g_type_check_instance_cast (GTypeInstance *type_instance,
 	g_warning ("invalid unclassed pointer in cast to `%s'",
 		   type_descriptive_name_I (iface_type));
     }
-  else
-    g_warning ("invalid cast from (NULL) pointer to `%s'",
-	       type_descriptive_name_I (iface_type));
   
   return type_instance;
 }
